--- /usr/src/asterisk-18.3.0/funcs/func_channel.c.orig	2021-03-25 13:34:21.000000000 -0400
+++ /usr/src/asterisk-18.3.0/funcs/func_channel.c	2021-05-17 10:07:36.481307754 -0400
@@ -20,6 +20,7 @@
  *
  * \author Kevin P. Fleming <kpfleming@digium.com>
  * \author Ben Winslow
+ * \author Naveen Albert <asterisk@phreaknet.org>
  *
  * \ingroup functions
  */
@@ -74,6 +75,14 @@
 			the channel's linkedid.</para>
 		</description>
 	</function>
+	<function name="OTHER_CHANNEL" language="en_US">
+		<synopsis>
+			Gets or sets variables on another channel
+		</synopsis>
+		<description>
+			<para>Allows access to any existing channel if it exists.</para>
+		</description>
+	</function>
 	<function name="CHANNEL" language="en_US">
 		<synopsis>
 			Gets/sets various pieces of information about the channel.
@@ -755,6 +764,76 @@
 	.write = func_mchan_write,
 };
 
+static int func_ochan_read(struct ast_channel *chan, const char *function,
+			     char *data, struct ast_str **buf, ssize_t len)
+{
+	struct ast_channel *ochan;
+	char *template = ast_alloca(4 + strlen(data));
+	
+	AST_DECLARE_APP_ARGS(args,
+			     AST_APP_ARG(var);
+			     AST_APP_ARG(channel);
+	);
+	AST_STANDARD_APP_ARGS(args, data);
+
+	if (!args.channel) {
+		ast_log(LOG_WARNING, "No channel was provided to %s function.\n", function);
+		return -1;
+	}
+	if (!(ochan = ast_channel_get_by_name(args.channel))) {
+		ast_log(LOG_ERROR, "Channel '%s' not found!  Variable '%s' will be blank.\n", args.channel, args.var);
+		return -1;
+	}
+	if (!args.var) {
+		ast_log(LOG_WARNING, "No variable name was provided to %s function.\n", function);
+		return -1;
+	}
+
+	sprintf(template, "${%s}", data); /* SAFE */
+	ast_str_substitute_variables(buf, len, ochan, template);
+	if (ochan) {
+		ast_channel_unref(ochan);
+	}
+	return 0;
+}
+
+static int func_ochan_write(struct ast_channel *chan, const char *function,
+			      char *data, const char *value)
+{
+	struct ast_channel *ochan;
+	
+	AST_DECLARE_APP_ARGS(args,
+			     AST_APP_ARG(var);
+			     AST_APP_ARG(channel);
+	);
+	AST_STANDARD_APP_ARGS(args, data);
+
+	if (!args.channel) {
+		ast_log(LOG_WARNING, "No channel was provided to %s function.\n", function);
+		return -1;
+	}
+	if (!(ochan = ast_channel_get_by_name(args.channel))) {
+		ast_log(LOG_ERROR, "Channel '%s' not found!  Variable '%s' will be blank.\n", args.channel, args.var);
+		return -1;
+	}
+	if (!args.var) {
+		ast_log(LOG_WARNING, "No variable name was provided to %s function.\n", function);
+		return -1;
+	}
+
+	pbx_builtin_setvar_helper(ochan, data, value);
+	if (ochan) {
+		ast_channel_unref(ochan);
+	}
+	return 0;
+}
+
+static struct ast_custom_function ochan_function = {
+	.name = "OTHER_CHANNEL",
+	.read2 = func_ochan_read,
+	.write = func_ochan_write,
+};
+
 static int unload_module(void)
 {
 	int res = 0;
@@ -762,6 +841,7 @@
 	res |= ast_custom_function_unregister(&channel_function);
 	res |= ast_custom_function_unregister(&channels_function);
 	res |= ast_custom_function_unregister(&mchan_function);
+	res |= ast_custom_function_unregister(&ochan_function);
 
 	return res;
 }
@@ -773,6 +853,7 @@
 	res |= ast_custom_function_register(&channel_function);
 	res |= ast_custom_function_register(&channels_function);
 	res |= ast_custom_function_register(&mchan_function);
+	res |= ast_custom_function_register(&ochan_function);
 
 	return res;
 }
